===
API
===

.. module:: nnfigs

The library provides classes which are usable by third party tools.

.. note::

    This project is still in *beta* stage, so the API is not finalized yet.

Modules:

.. toctree::
   :maxdepth: 2

   nnfigs.config <api_config>